@@ -2,8 +2,8 @@ from codepack.plugins.service import Service
 from typing import Union, TypeVar, Optional
 
 
-Storage = TypeVar('Storage', bound='codepack.storages.storage.Storage')
-Storable = TypeVar('Storable', bound='codepack.storages.storable.Storable')
+Storage = TypeVar('Storage', bound='codepack.storages.storage.Storage')  # noqa: F821
+Storable = TypeVar('Storable', bound='codepack.storages.storable.Storable')  # noqa: F821
 
 
 class StorageService(Service):
